.. _contents:

CellPyLib3d
===========

CellPyLib is a library for working with 1- and 2-dimensional _k_-color Cellular Automata in Python. CellPyLib-3d is an extension of this library, bringing support for 3-dimensional and 2-dimensional layered automata. Neighbourhood radii are adjustable and both Moore and von Neumann neighbourhoods are supported.

Utility functions for plotting and viewing the evolved CA are provided. These tools make it easy to visualize the
results of CA evolution.

.. toctree::
  :caption: Using CellPyLib3d
  :maxdepth: 5

  installation
  additional

.. toctree::
  :caption: Tutorials
  :maxdepth: 5

  neighbourhood
  colors
  threedim
  parallel
  gol

.. toctree::
  :caption: API Docs and License
  :maxdepth: 5

  reference
  Source <https://github.com/Cutwell/cellpylib-3d>
  license

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`